==> cra-template-adrinlol-1.3.5.tgz: package/README.md <==
## Free React landing page template

![landy](https://user-images.githubusercontent.com/48876996/100373174-cd393880-3023-11eb-9fef-8acdf9733120.gif)

[Landy][Landy] is a free React landing page template designed for developers and startups, who want to create a quick and professional landing page for their business or project.

This React template comes with multi-lingual support, smooth animations, set of ready to use sections and most importantly, all of the content is stored in the JSON files, so that you can manage the texts without having any prior knowledge in React.js.

## Table of contents

- [Features](#features)
- [Google Lighthouse](#google-lighthouse)
  - [Performance](#performance)
  - [Accessibility](#accessibility)
  - [Best Practices](#best-practices)
  - [SEO](#seo)
- [Demo](#demo)
- [Installation](#installation)
- [Special Thanks](#special-thanks)
- [Usage](#usage)
- [License](#license)

## Features

Your project will have everything you need to build a modern single-page React app:

- 🎁 **Modern** – Template created using the latest features of React (State management using Hooks, Code-Splitting to reduce the bundle size)

- 🏷 **Responsive** – Highly responsive and reusable UI components, that change depending on the provided props

- 🚀 **Fast** – Buttery smooth experience thanks to the implementation of best practices and no third party dependencies, resulting in <b>PERFECT</b> Google Lighthouse scores

- 🌍 **Internationalization** - Prebuilt standalone file that works in every environment and doesn't require reloading the page to translate the content

- 🛸 **Routing** - Each file inside the src/pages directory will generate its own route, so you don't have to manually handle the routing

- 🤙 **Contact Form** - Contact form written in React Hooks, with uncontrolled form validation to reduce unnecessary performance penalty. You just need to provide the endpoint

- ⚙️ **Maintenance** - All of the content is stored in the JSON files, so that you can easily manage the content of the website

## Google Lighthouse

![1](https://user-images.githubusercontent.com/48876996/104335960-555c9a00-550d-11eb-8e94-4549637f72bd.PNG)

[Google Lighthouse][Google Lighthouse] is an open-source, automated tool for measuring the quality of web pages. Google Lighthouse audits performance, accessibility and search engine optimization of web pages.

### Performance

Audits for metrics like first paint and time to interactive to determine lag.

### Accessibility

Checks for common issues that may prevent users from accessing your content.

### Best Practices

Looks for everything from HTTPS usage to correct image aspect ratios.

### SEO 

Checks for best practices to ensure your site is discoverable.


## Demo

Check the live demo here 👉️ https://landy.website/


### Installation

You’ll need to have Node 10.16.0 or later version on your local development machine (but it’s not required on the server). I recommend using the latest LTS version.

To create a new app, you have to:

### npx

Use the following command 

```sh
npx create-react-app my-app --template adrinlol
cd my-app
npm start
```

## What's included

- [axios][axios] - Promise based HTTP client for the browser and node.js
- [antd][antd] - React UI library that contains a set of high quality components.
- [react-reveal][react-reveal] - High performance animation library for React.
- [styled-componets][styled-componets] - Variant on “CSS-in-JS”—which solves many of the problems with traditional CSS.
- [i18next][i18next] - Internationalization-framework written in and for JavaScript.

## Special thanks

[whoooa][whoooa] - Use fantastic, handmade illustrations with easily changeable colors and different styles.

## Usage

Use it for whatever you want, and be sure to reach out to me on [Twitter](https://twitter.com/Adrinlolx) if you have any questions, or build something cool with it.

## License

Licensed under the MIT license.

<!-- prettier-ignore-start -->
[axios]: https://github.com/axios/axios
[antd]: https://github.com/ant-design/ant-design
[react-reveal]: https://github.com/rnosov/react-reveal
[styled-componets]: https://github.com/styled-components/styled-components
[i18next]: https://github.com/i18next/i18next
[whoooa]: https://www.whoooa.rocks/
[Landy]: https://www.npmjs.com/package/cra-template-adrinlol
[Google Lighthouse]: https://developers.google.com/web/tools/lighthouse
<!-- prettier-ignore-end -->

==> cra-template-adrinlol-1.3.6.tgz: package/README.md <==
## Free React landing page template

![landy](https://user-images.githubusercontent.com/48876996/119964629-74d6f980-bfba-11eb-8b29-9f8ddceb2a92.gif)

[Landy][Landy] is a free React landing page template written in TypeScript, designed for developers and startups, who want to create a quick and professional landing page for their business or project.

This React template comes with multi-lingual support, smooth animations, set of ready to use sections and most importantly, all of the content is stored in the JSON files, so that you can manage the texts without having any prior knowledge in React.js.

## Table of contents

- [Features](#features)
- [Google Lighthouse](#google-lighthouse)
  - [Performance](#performance)
  - [Accessibility](#accessibility)
  - [Best Practices](#best-practices)
  - [SEO](#seo)
- [Demo](#demo)
- [Installation](#installation)
- [Special Thanks](#special-thanks)
- [Usage](#usage)
- [License](#license)

## Features

Your project will have everything you need to build a modern single-page React app:

- 🎁 **Modern** – Template created using the latest features of React (State management using Hooks, Code-Splitting to reduce the bundle size)

- 💻 **Responsive** – Highly responsive and reusable UI components, that change depending on the provided props

- 🚀 **Fast** – Buttery smooth experience thanks to the implementation of best practices and no third party dependencies, resulting in <b>PERFECT</b> Google Lighthouse scores

- 🏷 **TypeScript support** – Landy is written in TypeScript to improve the DX

- 🌍 **Internationalization** - Prebuilt standalone file that works in every environment and doesn't require reloading the page to translate the content

- 🛸 **Routing** - Each file inside the src/pages directory will generate its own route, so you don't have to manually handle the routing

- 🤙 **Contact Form** - Contact form written in React Hooks, with uncontrolled form validation to reduce unnecessary performance penalty. You just need to provide the endpoint

- ⚙️ **Maintenance** - All of the content is stored in the JSON files, so that you can easily manage the content of the website

## Google Lighthouse

![1](https://user-images.githubusercontent.com/48876996/119963618-5e7c6e00-bfb9-11eb-8c0e-d4fe48c314f8.PNG)

[Google Lighthouse][Google Lighthouse] is an open-source, automated tool for measuring the quality of web pages. Google Lighthouse audits performance, accessibility and search engine optimization of web pages.

### Performance

Audits for metrics like first paint and time to interactive to determine lag.

### Accessibility

Checks for common issues that may prevent users from accessing your content.

### Best Practices

Looks for everything from HTTPS usage to correct image aspect ratios.

### SEO 

Checks for best practices to ensure your site is discoverable.


## Demo

Check the live demo here 👉️ https://landy.website/


### Installation

You’ll need to have Node 10.16.0 or later version on your local development machine (but it’s not required on the server). I recommend using the latest LTS version.

To create a new app, you have to:

### npx

Use the following command 

```sh
npx create-react-app my-app --template adrinlol
cd my-app
npm start
```

## What's included

- [axios][axios] - Promise based HTTP client for the browser and node.js
- [antd][antd] - React UI library that contains a set of high quality components.
- [react-awesome-reveal][react-awesome-reveal] - High performance animation library that adds reveal animations using the Intersection Observer API.
- [styled-componets][styled-componets] - Variant on “CSS-in-JS”—which solves many of the problems with traditional CSS.
- [i18next][i18next] - Internationalization-framework written in and for JavaScript.

## Special thanks

[whoooa][whoooa] - Use fantastic, handmade illustrations with easily changeable colors and different styles.

## Usage

Use it for whatever you want, and be sure to reach out to me on [Twitter](https://twitter.com/Adrinlolx) if you have any questions, or build something cool with it.

## License

Licensed under the MIT license.

<!-- prettier-ignore-start -->
[axios]: https://github.com/axios/axios
[antd]: https://github.com/ant-design/ant-design
[react-awesome-reveal]: https://www.npmjs.com/package/react-awesome-reveal
[styled-componets]: https://github.com/styled-components/styled-components
[i18next]: https://github.com/i18next/i18next
[whoooa]: https://www.whoooa.rocks/
[Landy]: https://www.npmjs.com/package/cra-template-adrinlol
[Google Lighthouse]: https://developers.google.com/web/tools/lighthouse
<!-- prettier-ignore-end -->
